window.Gleam.initSearch([{"doc":"owoify_gleam","title":"owoify_gleam","content":"# owoify_gleam\nTurning your worst nightmare into a Gleam package on Hex.\n\n[![Package Version](https://img.shields.io/hexpm/v/owoify_gleam)](https://hex.pm/packages/owoify_gleam)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/owoify_gleam/)\n\n- [Hex package](https://hex.pm/packages/owoify_gleam)\n\nThis is a Gleam port of [mohan-cao&#39;s owoify-js](https://github.com/mohan-cao/owoify-js), which will help you turn any string into nonsensical babyspeak similar to LeafySweet&#39;s infamous Chrome extension.\n\nJust like my other Owoify ports, three levels of owoness are available:\n\n1. **owo (default):** The most vanilla one.\n2. **uwu:** The moderate one.\n3. **uvu:** Litewawwy unweadabwal.\n\nPlease refer to the [original owoify-js](https://github.com/mohan-cao/owoify-js) repository for more information.\n\nRight now Gleam&#39;s stdlib doesn&#39;t have a comprehensive regular expression support. Thankfully, Gleam has wonderful support for Erlang FFI. Therefore, currently this library is just a thin wrapper of my [owoify_erl](https://github.com/deadshot465/owoify_erl). \n\n# Reason for development\n\nEven though Gleam&#39;s Erlang FFI support is excellent, calling functions written in Erlang still requires you manually write external functions, which can be painstaking depending on how many external functions you want to call. Therefore, [owoify_gleam](https://github.com/deadshot465/owoify_gleam) is just a thin wrapper of my [owoify_erl](https://github.com/deadshot465/owoify_erl) that does exactly that for you.\n\nAlso Gleam is cool! 😌\n\n# Installation\n\n```sh\ngleam add owoify_gleam\n```\n\n# Usage\n\n```gleam\nimport gleam/io\nimport owoify_gleam\n\npub fn main() {\n  owoify_gleam.owoify(&quot;This is the string to owo! Kinda cute isn&#39;t it?&quot;)\n  |&gt; io.println()\n\n  owoify_gleam.owoify_with_level(&quot;This is the string to owo! Kinda cute isn&#39;t it?&quot;, owoify_gleam.Uvu)\n  |&gt; io.println()\n}\n\n// Possible output\n// This is teh stwing two owo! Kinda cute isn&#39;t it?\n// fwis is teh stwing two owowowouwu Kinda cute isn&#39;t it?\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/owoify_gleam&gt;.\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\ngleam shell # Run an Erlang shell\n```\n\n## Disclaimer\n\nAs always, this package is written for practicing and bots&#39; needs. Performance is **NOT** guaranteed.\n\nThat being said, PRs are always welcomed.\n\n## See also\n- [owoify-js](https://github.com/mohan-cao/owoify-js) - The original owoify-js repository.\n- [Owoify.Net](https://www.nuget.org/packages/Owoify.Net/1.0.1) - The C# port of Owoify written by me.\n- [Owoify++](https://github.com/deadshot465/OwoifyCpp) - The C++ header-only port of Owoify written by me.\n- [owoify_rs](https://crates.io/crates/owoify_rs) - The Rust port of Owoify written by me.\n- [owoify-py](https://pypi.org/project/owoify-py/) - The Python port of Owoify written by me.\n- [owoify_dart](https://pub.dev/packages/owoify_dart) - The Dart port of Owoify written by me.\n- [owoify_rb](https://rubygems.org/gems/owoify_rb) - The Ruby port of Owoify written by me.\n- [owoify-go](https://pkg.go.dev/github.com/deadshot465/owoify-go) - The Go port of Owoify written by me.\n- [owoifySwift](https://github.com/deadshot465/OwoifySwift) - The Swift port of Owoify written by me.\n- [owoifyKt](https://search.maven.org/search?q=g:%22io.github.deadshot465%22%20AND%20a:%22owoifyKt%22) - The Kotlin port of Owoify written by me.\n- [owoify_ex](https://hex.pm/packages/owoify_ex) - The Elixir port of Owoify written by me.\n- [owoify_cr](https://crystalshards.org/shards/github/deadshot465/owoify_cr) - The Crystal port of Owoify written by me.\n- [owoifynim](https://nimble.directory/pkg/owoifynim) - The Nim port of Owoify written by me.\n- [owoify-clj](https://clojars.org/net.clojars.deadshot465/owoify-clj) - The Clojure port of Owoify written by me.\n- [purescript-owoify](https://pursuit.purescript.org/packages/purescript-owoify) - The PureScript port of Owoify written by me.\n- [owoify-hs](https://hackage.haskell.org/package/owoify-hs) - The Haskell port of Owoify written by me.\n- [owoify_erl](https://hex.pm/packages/owoify_erl) - The Erlang port of Owoify written by me.","url":"index.html"},{"doc":"owoify_gleam","title":"OwoifyLevel","content":"pub type OwoifyLevel {\n  Owo\n  Uwu\n  Uvu\n}\n\nOwo\n\n\nUwu\n\n\nUvu\n\n\nSynonyms:\nowoify_gleam.OwoifyLevel\nowoify_gleam OwoifyLevel","url":"owoify_gleam.html#OwoifyLevel"},{"doc":"owoify_gleam","title":"owoify","content":"pub fn owoify(source: String) -&gt; String\n The main entry point of `owoify_gleam`.\n This function will use the `Owo` owoness to owoify the source string.\n Returns the owoified string according to the passed owoify level.\nSynonyms:\nowoify_gleam.owoify\nowoify_gleam owoify","url":"owoify_gleam.html#owoify"},{"doc":"owoify_gleam","title":"owoify_with_level","content":"pub fn owoify_with_level(\n  source: String,\n  level: OwoifyLevel,\n) -&gt; String\n The main entry point of `owoify_gleam`.\n This function will require the user to explicitly pass the desired owoness to owoify the source string.\n Currently three owoify levels are supported: `Owo`, `Uwu`, `Uvu`.\n Returns the owoified string according to the passed owoify level.\nSynonyms:\nowoify_gleam.owoify_with_level\nowoify_gleam owoify_with_level","url":"owoify_gleam.html#owoify_with_level"},{"doc":"owoify_gleam","title":"uvuify","content":"pub fn uvuify(source: String) -&gt; String\n The main entry point of `owoify_gleam`.\n This function will use the `Uvu` owoness to owoify the source string.\n Returns the owoified string according to the passed owoify level.\nSynonyms:\nowoify_gleam.uvuify\nowoify_gleam uvuify","url":"owoify_gleam.html#uvuify"},{"doc":"owoify_gleam","title":"uwuify","content":"pub fn uwuify(source: String) -&gt; String\n The main entry point of `owoify_gleam`.\n This function will use the `Uwu` owoness to owoify the source string.\n Returns the owoified string according to the passed owoify level.\nSynonyms:\nowoify_gleam.uwuify\nowoify_gleam uwuify","url":"owoify_gleam.html#uwuify"},{"doc":"owoify_gleam","title":"owoify_gleam","content":"","url":"owoify_gleam.html"}]);